pub fn with_kind(repr: PersistentRepr, kind: EntryKind) -> PersistentReprExpand description
Push the provenance tag for kind onto repr without changing the
struct shape. Returns the repr by value for chaining.
pub fn with_kind(repr: PersistentRepr, kind: EntryKind) -> PersistentReprPush the provenance tag for kind onto repr without changing the
struct shape. Returns the repr by value for chaining.